==> moodle-4.1.6.zip: moodle/mod/label/lang/en/label.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'label', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package mod_label
 * @copyright  1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configdndmedia'] = 'Offer to create a Text and media area when media files are dragged and dropped onto a course.';
$string['configdndresizeheight'] = 'When a Text and media area is created from a dragged and dropped media file, resize it if it is higher than this many pixels. If set to zero, the media file will not be resized.';
$string['configdndresizewidth'] = 'When a Text and media area is created from a dragged and dropped media file, resize it if it is wider than this many pixels. If set to zero, the media file will not be resized.';
$string['dndmedia'] = 'Media drag and drop';
$string['dndresizeheight'] = 'Resize drag and drop height';
$string['dndresizewidth'] = 'Resize drag and drop width';
$string['dnduploadlabel'] = 'Add media to course page';
$string['dnduploadlabeltext'] = 'Add a Text and media area to the course page';
$string['indicator:cognitivedepth'] = 'Text and media area cognitive';
$string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Text and media area resource.';
$string['indicator:cognitivedepthdef'] = 'Text and media area cognitive';
$string['indicator:cognitivedepthdef_help'] = 'The participant has reached this percentage of the cognitive engagement offered by the Text and media area resources during this analysis interval (Levels = No view, View)';
$string['indicator:cognitivedepthdef_link'] = 'Learning_analytics_indicators#Cognitive_depth';
$string['indicator:socialbreadth'] = 'Text and media area social';
$string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Text and media area resource.';
$string['indicator:socialbreadthdef'] = 'Text and media area social';
$string['indicator:socialbreadthdef_help'] = 'The participant has reached this percentage of the social engagement offered by the Text and media area resources during this analysis interval (Levels = No participation, Participant alone)';
$string['indicator:socialbreadthdef_link'] = 'Learning_analytics_indicators#Social_breadth';
$string['label:addinstance'] = 'Add a new Text and media area';
$string['label:view'] = 'View Text and media area';
$string['labeltext'] = 'Text';
$string['modulename'] = 'Text and media area';
$string['modulename_help'] = 'The Text and media area enables you to display text and multimedia on the course page.

You can use a Text and media area to:

* Split up a long list of course activities with a subheading or an image
* Display an embedded video directly on the course page
* Add a short description to a course section';
$string['modulename_link'] = 'mod/label/view';
$string['modulenameplural'] = 'Text and media areas';
$string['privacy:metadata'] = 'The Text and media area plugin does not store any personal data.';
$string['pluginadministration'] = 'Text and media area administration';
$string['pluginname'] = 'Text and media area';
$string['search:activity'] = 'Text and media area';

==> moodle-4.3.zip: moodle/mod/label/lang/en/label.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'label', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package mod_label
 * @copyright  1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configdndmedia'] = 'Offer to create a Text and media area when media files are dragged and dropped onto a course.';
$string['configdndresizeheight'] = 'When a Text and media area is created from a dragged and dropped media file, resize it if it is higher than this many pixels. If set to zero, the media file will not be resized.';
$string['configdndresizewidth'] = 'When a Text and media area is created from a dragged and dropped media file, resize it if it is wider than this many pixels. If set to zero, the media file will not be resized.';
$string['dndmedia'] = 'Media drag and drop';
$string['dndresizeheight'] = 'Resize drag and drop height';
$string['dndresizewidth'] = 'Resize drag and drop width';
$string['dnduploadlabel'] = 'Add media to course page';
$string['dnduploadlabeltext'] = 'Add a Text and media area to the course page';
$string['indicator:cognitivedepth'] = 'Text and media area cognitive';
$string['indicator:cognitivedepth_help'] = 'This indicator is based on the cognitive depth reached by the student in a Text and media area resource.';
$string['indicator:cognitivedepthdef'] = 'Text and media area cognitive';
$string['indicator:cognitivedepthdef_help'] = 'The participant has reached this percentage of the cognitive engagement offered by the Text and media area resources during this analysis interval (Levels = No view, View)';
$string['indicator:cognitivedepthdef_link'] = 'Learning_analytics_indicators#Cognitive_depth';
$string['indicator:socialbreadth'] = 'Text and media area social';
$string['indicator:socialbreadth_help'] = 'This indicator is based on the social breadth reached by the student in a Text and media area resource.';
$string['indicator:socialbreadthdef'] = 'Text and media area social';
$string['indicator:socialbreadthdef_help'] = 'The participant has reached this percentage of the social engagement offered by the Text and media area resources during this analysis interval (Levels = No participation, Participant alone)';
$string['indicator:socialbreadthdef_link'] = 'Learning_analytics_indicators#Social_breadth';
$string['label:addinstance'] = 'Add a new Text and media area';
$string['label:view'] = 'View Text and media area';
$string['labelname'] = 'Name';
$string['labelname_help'] = 'The name is only used to identify the Text and media area in the course index and for activity completion. If you leave this empty, a name will automatically be generated using the first characters of the text.';
$string['labeltext'] = 'Text';
$string['modulename'] = 'Text and media area';
$string['modulename_help'] = 'The Text and media area enables you to display text and multimedia on the course page.

You can use a Text and media area to:

* Split up a long list of course activities with a subheading or an image
* Display an embedded video directly on the course page
* Add a short description to a course section';
$string['modulename_link'] = 'mod/label/view';
$string['modulenameplural'] = 'Text and media areas';
$string['privacy:metadata'] = 'The Text and media area plugin does not store any personal data.';
$string['pluginadministration'] = 'Text and media area administration';
$string['pluginname'] = 'Text and media area';
$string['search:activity'] = 'Text and media area';
